@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-
 """Humanizing functions for numbers."""
 from __future__ import annotations
 
@@ -10,10 +8,9 @@ from fractions import Fraction
 from typing import TYPE_CHECKING
 
 from .i18n import _gettext as _
-from .i18n import _ngettext
+from .i18n import _ngettext, decimal_separator, thousands_separator
 from .i18n import _ngettext_noop as NS_
 from .i18n import _pgettext as P_
-from .i18n import decimal_separator, thousands_separator
 
 if TYPE_CHECKING:
     if sys.version_info >= (3, 10):
@@ -66,6 +63,7 @@ def ordinal(value: NumberOrString, gender: str = "male") -> str:
         True
 
         ```
+
     Args:
         value (int, str, float): Integer to convert.
         gender (str): Gender for translations. Accepts either "male" or "female".
@@ -136,6 +134,7 @@ def intcomma(value: NumberOrString, ndigits: int | None = None) -> str:
         'None'
 
         ```
+
     Args:
         value (int, float, str): Integer or float to convert.
         ndigits (int, None): Digits of precision for rounding after the decimal point.
@@ -215,6 +214,7 @@ def intword(value: NumberOrString, format: str = "%.1f") -> str:
         '1.234 million'
 
         ```
+
     Args:
         value (int, float, str): Integer to convert.
         format (str): To change the number of decimal or general format of the number
@@ -282,6 +282,7 @@ def apnumber(value: NumberOrString) -> str:
       'None'
 
       ```
+
     Args:
         value (int, float, str): Integer to convert.
 
@@ -344,6 +345,7 @@ def fractional(value: NumberOrString) -> str:
         'None'
 
         ```
+
     Args:
         value (int, float, str): Integer to convert.
 
